@@ -13,8 +13,8 @@
 package No::Worries::Stat;
 use strict;
 use warnings;
-our $VERSION  = "0.9_1";
-our $REVISION = sprintf("%d.%02d", q$Revision: 1.12 $ =~ /(\d+)\.(\d+)/);
+our $VERSION  = "0.8";
+our $REVISION = sprintf("%d.%02d", q$Revision: 1.7 $ =~ /(\d+)\.(\d+)/);
 
 #
 # used modules
@@ -260,17 +260,23 @@ sub stat_type ($) {
     my($mode) = @_;
 
     unless (@_Mode2Type) {
-        eval { $_Mode2Type[S_IFREG()  >> _IBITS] = "plain file" };
-        eval { $_Mode2Type[S_IFDIR()  >> _IBITS] = "directory" };
-        eval { $_Mode2Type[S_IFIFO()  >> _IBITS] = "pipe" };
-        eval { $_Mode2Type[S_IFSOCK() >> _IBITS] = "socket" };
-        eval { $_Mode2Type[S_IFBLK()  >> _IBITS] = "block device" };
-        eval { $_Mode2Type[S_IFCHR()  >> _IBITS] = "character device" };
-        eval { $_Mode2Type[S_IFLNK()  >> _IBITS] = "symlink" };
-        eval { $_Mode2Type[S_IFDOOR() >> _IBITS] = "door" };
-        eval { $_Mode2Type[S_IFPORT() >> _IBITS] = "event port" };
-        eval { $_Mode2Type[S_IFNWK()  >> _IBITS] = "network file" };
-        eval { $_Mode2Type[S_IFWHT()  >> _IBITS] = "whiteout" };
+        # standard
+        $_Mode2Type[S_IFREG()  >> _IBITS] = "plain file";
+        $_Mode2Type[S_IFBLK()  >> _IBITS] = "block device";
+        $_Mode2Type[S_IFCHR()  >> _IBITS] = "character device";
+        $_Mode2Type[S_IFDIR()  >> _IBITS] = "directory";
+        $_Mode2Type[S_IFIFO()  >> _IBITS] = "pipe";
+        $_Mode2Type[S_IFLNK()  >> _IBITS] = "symlink";
+        $_Mode2Type[S_IFSOCK() >> _IBITS] = "socket";
+        # optional
+        $_Mode2Type[S_IFDOOR() >> _IBITS] = "door"
+            if defined(&S_IFDOOR);
+        $_Mode2Type[S_IFPORT() >> _IBITS] = "event port"
+            if defined(&S_IFPORT);
+        $_Mode2Type[S_IFNWK()  >> _IBITS] = "network file"
+            if defined(&S_IFNWK);
+        $_Mode2Type[S_IFWHT()  >> _IBITS] = "whiteout"
+            if defined(&S_IFWHT);
     }
     $mode &= S_IFMT;
     $mode >>= _IBITS;
@@ -308,11 +314,11 @@ No::Worries::Stat - stat() handling without worries
   printf("user can read\n") if $stat[ST_MODE] & S_IRUSR;
 
   # make sure "/bin/ls" is owned by root and has the right permissions
-  stat_ensure("/bin/ls", user => "root", mode => 0755);
+  state_ensure("/bin/ls", user => "root", mode => 0755);
   # make sure "/var/log" is not group or world writable
-  stat_ensure("/var/log", mode => "-022");
+  state_ensure("/var/log", mode => "-022");
   # idem but using the S_* constants
-  stat_ensure("/var/log", mode => "-" . (S_IWGRP|S_IWOTH));
+  state_ensure("/var/log", mode => "-" . (S_IWGRP|S_IWOTH));
 
 =head1 DESCRIPTION
 
@@ -381,7 +387,7 @@ number of 512B blocks allocated
 
 =back
 
-In addition, it also optionally exports all the ":mode" constants from L<Fcntl>.
+In addition, it also optionally exports all the "mode" constants from L<Fcntl>.
 
 This way, all the stat() related constants can be imported in a uniform way.
 
@@ -397,13 +403,12 @@ exported by default):
 given the file mode (C<ST_MODE> field), return the file type as a string;
 possible return values are: "block device", "character device", "directory",
 "door", "event port", "network file", "pipe", "plain file", "socket",
-"symlink", "unknown" and "whiteout".
+"symlink" and "whiteout".
 
 =item stat_ensure(PATH[, OPTIONS])
 
 make sure the given path has the expected file "status" (w.r.t. stat()) and
-call chown(), chmod() or utime() if needed, returning the number of changes
-performed; supported options:
+call chown(), chmod() or utime() if needed, supported options:
 
 =over
 
@@ -459,7 +464,7 @@ Here is for insatnce how a "noaction" option could be implemented:
       return(0);
   }
   foreach my $path (@paths) {
-      stat_ensure($path, user => "root", mode => 0755, callback => \&noaction);
+      state_ensure($path, user => "root", mode => 0755, callback => \&noaction);
   }
 
 =head1 SEE ALSO
@@ -471,4 +476,4 @@ L<No::Worries>.
 
 Lionel Cons L<http://cern.ch/lionel.cons>
 
-Copyright (C) CERN 2012-2013
+Copyright CERN 2012
